#
# spec file for package bcm20702a1-firmware
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!_firmwaredir:%define _firmwaredir /lib/firmware}

Name:           bcm20702a1-firmware
Version:        1201650
Release:        9.6
Summary:        Firmware for BCM20702A1 based devices
License:        MIT
URL:            https://www.asus.com/Networking/USBBT400/
Requires(post): bluez
Requires(post): coreutils
Requires(post): unzip
Requires(post): wget
# Another variant: bsc#1087996
Supplements:    modalias(usb:v0A5Cp21E6d*dcFFdsc01dp01icFFisc*ip*in*)
# Expand with more hardware if found
Supplements:    modalias(usb:v0A5Cp21E6d0112dcFFdsc01dp01icFFisc*ip*in*)
BuildArch:      noarch

%description
Firmware for broadcom BCM20702A1 based devices present in various sticks and
laptops always over usb bridge.

%prep
:

%build
:

%install
mkdir -p %{buildroot}%{_firmwaredir}/brcm
:

%post
OUT="$(mktemp -d)"
cd "$OUT"
wget -q https://dlcdnet.asus.com/pub/ASUS/misc/BT/Bluetooth_V%{version}_WHQL_Win10.zip || :
if [ ! -f Bluetooth_V%{version}_WHQL_Win10.zip ]; then
    echo "Fatal error in obtaining the Windows bluetooth driver: Bluetooth_V%{version}_WHQL_Win10.zip"
else
    unzip Bluetooth_V%{version}_WHQL_Win10.zip
    cd Bluetooth
    hex2hcd BCM_DriverOnly/64/BCM20702A1_001.002.014.1443.1467.hex \
        -o BCM20702A1-0b05-17cb.hcd
    hex2hcd BCM_DriverOnly/64/BCM20702A1_001.002.014.1443.1469.hex \
        -o BCM20702A1-0b05-17cf.hcd
    hex2hcd BCM_DriverOnly/64/BCM20702A1_001.002.014.1483.1647.hex \
        -o BCM20702A1-05ac-21e1.hcd
    hex2hcd BCM_DriverOnly/64/BCM20702A1_001.002.014.1483.1669.hex \
        -o BCM20702A1-0a5c-21e6.hcd
    hex2hcd BCM_DriverOnly/64/BCM20702A1_001.002.014.1443.1467.hex \
        -o BCM20702A1-050d-065a.hcd
    mkdir -p %{_firmwaredir}/brcm/
    install -m644 BCM20702A1-0b05-17cb.hcd %{_firmwaredir}/brcm/BCM20702A1-0b05-17cb.hcd
    install -m644 BCM20702A1-0b05-17cf.hcd %{_firmwaredir}/brcm/BCM20702A1-0b05-17cf.hcd
    install -m644 BCM20702A1-05ac-21e1.hcd %{_firmwaredir}/brcm/BCM20702A1-05ac-21e1.hcd
    install -m644 BCM20702A1-0a5c-21e6.hcd %{_firmwaredir}/brcm/BCM20702A1-0a5c-21e6.hcd
    install -m644 BCM20702A1-050d-065a.hcd %{_firmwaredir}/brcm/BCM20702A1-050d-065a.hcd
fi
# Another variant: bsc#1087996
wget -q https://s3.amazonaws.com/plugable/bin/fw-0a5c_21e8.hcd || :
if [ ! -f fw-0a5c_21e8.hcd ]; then
    echo "Fatal error in obtaining the 0a5c:21e8 BT firmware"
else
    install -m644 fw-0a5c_21e8.hcd %{_firmwaredir}/brcm/BCM20702A1-0a5c-21e8.hcd
fi
rm -rf "$OUT"
exit 0

%files
%dir %{_firmwaredir}/brcm
%ghost %{_firmwaredir}/brcm/BCM20702A1-0b05-17cb.hcd
%ghost %{_firmwaredir}/brcm/BCM20702A1-0b05-17cf.hcd
%ghost %{_firmwaredir}/brcm/BCM20702A1-05ac-21e1.hcd
%ghost %{_firmwaredir}/brcm/BCM20702A1-0a5c-21e6.hcd
%ghost %{_firmwaredir}/brcm/BCM20702A1-0a5c-21e8.hcd
%ghost %{_firmwaredir}/brcm/BCM20702A1-050d-065a.hcd

%changelog
* Mon Apr 25 2022 tiwai@suse.de
- Drop superfluous dependency on kernel-firmware (bsc#1198795)
* Sun Mar 21 2021 Michal Suchanek <msuchanek@suse.com>
- Fix build on Leap which does not have %%_firmwaredir
* Sat Feb 27 2021 Javier S. Pedro <dev.rpm@javispedro.com>
- fix boo#1175038 - remove unnecessary %%postun scriptlet that is
  incorrectly deleting all package files on upgrade; all files are
  already listed in %%files as %%ghost so no scriptlet is needed.
* Mon Oct 19 2020 Ludwig Nussel <lnussel@suse.de>
- use %%_firmwaredir
* Sun Jun 21 2020 Adrian Schröter <adrian@suse.de>
- add support for BCM20702A1-050d-065a.hcd
  (050d:065a Belkin Components F8T065BF Mini Bluetooth 4.0 Adapter)
* Tue Oct 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use https to fetch the archive bsc#1154083
* Tue Oct 30 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid bashisms in %%post
* Mon Oct 29 2018 tiwai@suse.de
- Fetch & install another variant firmware (0a5c:21e8) (bsc#1087996)
* Tue Feb 14 2017 matz.fuchs@gmx.at
- Fix typo in filelist, add one additional firmware file
* Wed Mar 23 2016 tchvatal@suse.com
- Try to add modalias to auto install on hardware that requires it
* Mon Mar 21 2016 tchvatal@suse.com
- Update the filelist to avoid conflict with kernel-firmware
* Fri Feb 19 2016 tchvatal@suse.com
- Convert to download on user machine rather than have unknown license file
* Sun Feb 14 2016 tchvatal@suse.com
- Initial commit, adapted from AUR
